;
;
; PROGRAM: Little Dude 2 trainer
; VERSION: 1.00
; AUTHOR:  David Eriksson <david@2goodsoft.com>
; DATE:    05/03/98
;
; Keeps health, lives & ammo at a constant level.
;
; To find out the right memory locations and to test the trainer during
; development I used CalcEm - The Calculator Emulator.
;		http://www.2goodsoft.com/calcem/
; (In fact, this have not yet been tested on a calculator!)
;
; The interrupt stuff is an almost exact rip of Crash to CrASH v1.3
;
;

.NOLIST
#INCLUDE "crash82.inc"
.LIST

.DB "Little Dude 2 Trainer",0

INT_LD2TRAIN	.EQU	0d2h	; I have no registered ID byte :-(((

;
; Main
;
Main:
	call	CR_GRBCopy			; Clear screen

	SET		3, (IY+05)			; Display inverted
	ld		hl, szInfo
	ROM_CALL(D_ZT_STR)
	RES		3, (IY+05)			; Display normal
	ROM_CALL(NEXT_LINE)

	ld		a, (INT_STATE)		; Check out CrASH's interrupt byte
	cp		INT_LD2TRAIN
	jr		z, Remove
	
	or		a
	jr		z, Install
	
	ld		hl, szAnother
	ROM_CALL(D_ZT_STR)

WaitKey:                   ; After this, it will return to CrASH
	jp		CR_KHAND

;
; Install interrupt
;
Install:
	ld		hl, szInstall
	ROM_CALL(D_ZT_STR)
	
	ld		hl, 8400h
	ld		de, 8401h
	ld		(hl), 83h
	ld		bc, 100h
	ldir
	
	ld		hl, IntProcStart
	ld		de, 8383h
	ld		bc, IntProcEnd-IntProcStart+1
	ldir
	
	ld		hl, 15bh
	ld		(APD_FREE), HL
	
	ld		a, 84h
	ld		i, a
	
	im		2
	
	jr		WaitKey

;
; Remove interrupt
;
Remove:
	ld		hl, szRemove
	ROM_CALL(D_ZT_STR)
	
	im		1
	
	ld		hl, 300h
	ld		(APD_FREE), hl
	
	xor		a
	ld		i, a
	ld		(INT_STATE), a
		
	jr		WaitKey

;
; Interrupt proc
;
IntProcStart:
	di
	ex		af, af'
	exx
	
	; Set CrASH's interrupt byte
	ld		a, INT_LD2TRAIN
	ld		(INT_STATE), A
	
	; Check 'location'
	ld		a, (8121h)
	cp		0ffh			; Inside CrASH?
	jr		nz, ExitInt
		
	;
	; We're modifying inside TEXT_MEM so no one gets hurt...
	;
	
	ld		a, 063h

	ld		(80a7h), a		; Health
	ld		(80cch), a		; Lives

	ld		(80d1h), a		; Shotgun
	ld		(80d2h), a		; Freeze ray
	ld		(80d3h), a		; Rocket launcher
	ld		(80d4h), a		; Grenades
	
ExitInt:
	exx
	ex		af, af'
	jp		38h

IntProcEnd:

;
; Static data
;
szInfo:
.DB		"  LD 2 Trainer  "
.DB		"       by       "
.DB		" David Eriksson ",0

szInstall:
.DB		" Installing.... ",0

szRemove:
.DB		"  Removing....  ",0

szAnother:	
.DB		"Another handler "
.DB		"is running. Turn"
.DB		"off to cheat!",0
